EMI 2 - Analyser les Images (Education aux médias)

Hygiène Mentale

EMI 2 - Analyser les Images (Education aux médias)

Le projet de Rose-Marie Farinella, institutrice en Haute Savoie, qui anime des ateliers dans cette classe de CM2 une fois par semaine.
A chaque fois, les élèves enfilent leur masque de "HoaxBuster", de SuperHéros du journalisme, qui chassent les fausses informations.
- Croiser les informations
- Remonter à la source
- Détecter les canulars et les rumeurs
- Faire le tri entre l'info et l'intox
" Si on avait un véritable système éducatif dans ce pays, on y donnerait des cours d'Autodéfense Intellectuelle" (Noam Chomsky)
Partie 1 : Education aux Medias et à l'Information
https://youtu.be/__DVwG9oiuU
Partie 2 : Analyser les images
https://youtu.be/miJ2ObMs-I4
Partie 3 : Remonter à la Source de l'Information
https://youtu.be/0ig87rUmwc8
Partie 4 : La propagation des rumeurs
https://youtu.be/8xOn_ChBHCw
Interview de Rose MarieFarinella
(Bientôt)
______________________________________________
Ressources :
Education aux Medias et à l'information dans les programmes
http://eduscol.education.fr/cid72525/l-emi-et-la-strategie-du-numerique.html
Le projet EMI de Rose Marie Farinella (Toutes les ressources pédagogiques)
http://www.ac-grenoble.fr/ien.cluses/spip.php?article583
Tous les dessins des élèves :
http://www.ac-grenoble.fr/ien.cluses/spip.php?article678
Rose-Marie a reçu le "Prix éducation aux médias" aux Assises du journalisme 2016
http://www.ac-grenoble.fr/ien.cluses/spip.php?article658
_
Musique d'intro : Kevin McLeod
Le facebook : http://facebook.com/HygieneMentale
Le site : http://laelith.fr/Zet
L'association : http://zetetique.fr
Le Tipee : https://www.tipeee.com/hygiene-mentale

10/10/2016